@@ -1,5 +1,7 @@
 lsd.test <- function (resp, alternative = 1, null = NULL, D = NULL){
 
+  call <- match.call()
+  
   resp=as.matrix(resp)
   n <- dim(resp)[1]
   p <- dim(resp)[2]
@@ -21,7 +23,7 @@ lsd.test <- function (resp, alternative = 1, null = NULL, D = NULL){
 
   if (is.null(D)) {
    D=diag(t(resp)%*%IP0%*%resp)  
-  }else   if(is.function(D)) D <- D(resp=resp,null=null)
+  } else   if(is.function(D)) D <- D(resp=resp,null=null)
   D <- as.matrix(D)  
   q <- dim(D)[2]
    
@@ -29,8 +31,14 @@ lsd.test <- function (resp, alternative = 1, null = NULL, D = NULL){
   G <- t(resp)%*%IP0%*%resp - H
   DHD	 <- t(D) %*% H %*% D
   DGD <- t(D) %*% G %*% D
-  df=c(q-1+k,n-h-k+1-q)
-  F <- df[2]/df[1]*sum(diag(DHD))/sum(diag(DGD))
-  p <- 1-pf(F,df[1],df[2])
-  list(F=F,df=df,p=p,D=D)
+  
+  
+  out <- new("lsd.object")  
+  out @ call = call
+  out @ df = c(q-1+k,n-h-k+1-q)
+  out @ F = out@df[2]/out@df[1]*sum(diag(DHD))/sum(diag(DGD))
+  out @ globalP = 1-pf(F,out@df[1],out@df[2])
+  out @ D = D
+  
+  return(out)
 }
\ No newline at end of file
